#
# spec file for package tvtime
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tvtime
Version:        1.0.11
Release:        3.3
Summary:        High Quality Television Application
License:        GPL-2.0-or-later
Group:          Hardware/TV
Url:            http://tvtime.net/
Source:         http://www.linuxtv.org/downloads/tvtime/%{name}-%{version}.tar.gz
Patch0:         tvtime-1.0.11-sysmacros.diff
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%lang_package

%description
tvtime is a high quality television application for use with video
capture cards.	tvtime processes the input from a capture card and
displays it on a computer monitor or projector.  Unlike other
television applications, tvtime focuses on high visual quality.

%prep
%autosetup -p1

%build
#autoreconf -i -f
%ifarch %ix86
RPM_OPT_FLAGS="%{optflags} -mmmx"
export CXXFLAGS="-mmmx"
%endif
export CFLAGS="%{optflags}"
%configure --with-pic
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%suse_update_desktop_file -i tvtime AudioVideo TV
%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-, root, root)
%doc NEWS AUTHORS COPYING ChangeLog README docs/html
%doc data/COPYING*
%{_bindir}/*
%dir %{_sysconfdir}/tvtime
%config(noreplace) %{_sysconfdir}/tvtime/*
%{_datadir}/tvtime
%{_datadir}/applications/tvtime.desktop
%{_datadir}/appdata/tvtime.appdata.xml
%dir %{_datadir}/appdata/
%{_datadir}/icons/hicolor/*/apps/tvtime.*
%{_mandir}/*/*

%files lang -f %{name}.lang
%defattr(-, root, root)

%changelog
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Feb 23 2019 seife+obs@b1-systems.com
- add tvtime-1.0.11-sysmacros.diff to build with current glibc
* Mon Feb  6 2017 mailaender@opensuse.org
- Update to version 1.0.11
- Drop tvtime-gcc6-fixes.patch
* Thu Jun 23 2016 tiwai@suse.de
- Fix build errors with gcc6: all are about spaces with literals
  tvtime-gcc6-fixes.patch
* Mon Feb 15 2016 eshmarnev@suse.com
- A Patch tvtime.linux-compiler.patch is being deleted
- A Patch tvtime-glibc.patch is being deleted
- A Patch tvtime-1.0.2-videoinput.patch is being deleted
- A Patch tvtime-gcc41.patch is being deleted
- A Patch tvtime-libpng15.patch is being deleted
* Thu Nov  5 2015 p.drouand@gmail.com
- Update to version 1.0.8
  * Change translation man pages and messages to use UTF-8
- Changes from version 1.0.7
  * Fix warning about Makefiles ignoring the --datarootdir parameter
  * Remove unused functions
  * Safely assume C89 semantics and make RETSIGTYPE void
  * Replace deprecated function XKeycodeToKeysym with XkbKeycodeToKeysym
  * Add gitignore to plugins directory
  * Link to libsupc++ instead of bringing in libstdc++.
  * Actually call function
  * Set subdir-objects automake option
  * Revert "Set subdir-objects option for automake"
  * Set automake flavour to foreign
  * Set subdir-objects option for automake
  * Revert accidental replacement of INSTALL file
  * Turn automake silent by default
  * Fix bashisms in boostrap
  * Remove unused safetytime variable
  * Remove embedded Debian packaging directory
- Do not longer ship INSTALL file
* Sun Feb 15 2015 crrodriguez@opensuse.org
-  Update to tvtime 1.0.6.
- Update URL/Source locations for future updates
- Remove all patches since none are needed now.
- tvtime now uses alsa instead of OSS emulation.
* Sat Nov  8 2014 crrodriguez@opensuse.org
- Run spec cleaner
- replace use of xorg-x11-devel by individual pkgconfig()
  buildrequires.
* Thu Aug 30 2012 pgajdos@suse.com
- package builds also against libpng15
  * tvtime-libpng15.patch
* Mon Feb 20 2012 coolo@suse.com
- add explicit buildrequire on xorg-x11-devel
* Tue Nov 22 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Jun  4 2009 coolo@suse.de
- fix build with new glibc
* Sun Feb 24 2008 crrodriguez@suse.de
- use find_lang macro to create a proper language list
* Mon Aug  6 2007 olh@suse.de
- remove inclusion of linux/compiler.h
* Tue Mar 13 2007 anschneider@suse.de
- tvtime-1.0.2-videoinput.patch:
  VIDIOC_DQBUF called without setting cur_buf.memory
* Mon Oct 16 2006 ro@suse.de
- remove DirectFB from BuildRequires (unused)
* Mon Jan 30 2006 hvogel@suse.de
- fix buildrequires again
* Fri Jan 27 2006 hvogel@suse.de
- add libpng-devel and freetype2-devel to buildrequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 hvogel@suse.de
- update to version 1.0.2
* Fri Jan 13 2006 hvogel@suse.de
- update to version 1.0.1
* Mon Oct 17 2005 hvogel@suse.de
- removed some extra qualifications to make gcc happy again
* Thu Jun 23 2005 hvogel@suse.de
- mark config file as noreplace
* Wed May 18 2005 hvogel@suse.de
- also use -mmmx for c++
* Mon May 16 2005 ro@suse.de
- add -mmmx on x86
* Mon May  9 2005 hvogel@suse.de
- Update to version 0.99
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Fri Nov  5 2004 hvogel@suse.de
- update to version 0.9.15
* Thu Oct  7 2004 hvogel@suse.de
- update version to 0.9.13
* Thu Jan 29 2004 hvogel@suse.de
- mark config files as config
- mark man pages as documentation
- use bzip2 for the source
* Thu Jan  8 2004 hvogel@suse.de
- remove localstatedir/fifogroup usage
- stop moving desktop file around
* Mon Dec  1 2003 hvogel@suse.de
- readd part of the non intel patch
* Wed Nov 26 2003 hvogel@suse.de
- update to version 0.9.12
* Fri Nov 14 2003 meissner@suse.de
- do not do Intel specific stuff on non-i386 (loading of
  windows dlls, ioperm() and inb()).
- 2 pointer accesses (and probably more) are not 64bit clean.
- fixed destdir patch.
* Thu Nov 13 2003 hvogel@suse.de
- dont build as root
* Mon Oct 13 2003 hvogel@suse.de
- Initial package version 0.9.10
